@@ -1,4 +1,5 @@
 from math import inf
+import random
 from collections import defaultdict
 from .vertices import Vertices
 from .edges import Edges
@@ -30,7 +31,10 @@ class Graph:
       
   def parse_vertices(self, vertices):
     for u in vertices:
-      self.add_vertex(u)
+      if type(u) is list:
+        self.add_vertex(u[0], **u[1])
+      else:
+        self.add_vertex(u)
       
   def parse_edges(self, edges):
     if edges is None:
@@ -217,15 +221,29 @@ class Graph:
           return True
       return False
 
+  def edge_weight(self, u, v):
+    return self.E[u, v].weight if hasattr(self.E[u, v], 'weight') else 1.0
+
+  def vertex_weight(self, v):
+    return self.vertex(v).weight if hasattr(self.vertex(v), 'weight') else 1.0
+
   def total_edge_weight(self, v=None):
     if v is None:
         return sum([self.total_edge_weight(v) for v in self.vertices])
     if not self.has_vertex(v):
       return 0
-    return sum([self.E[n, v].weight if hasattr(self.E[n, v], 'weight') else 1.0 for n in self.E.reverse_neighbors(v)])
-  
+    return sum([self.edge_weight(n, v) for n in self.E.reverse_neighbors(v)])
+
   def total_vertex_weight(self):
-    return sum([self.vertex(v).weight if hasattr(self.vertex(v), 'weight') else 1.0 for v in self.vertices])
+    return sum([self.vertex_weight(v) for v in self.vertices])
+
+  def generate_random_graph(self, n, p):
+    for i in range(n):
+      self.add_vertex(str(i+1))
+    for i in self.vertices:
+      for j in self.vertices:
+        if (i != j and random.random() < p):
+          self.add_edge(i, j)
 
   def find_isolated_vertices(self):
     isolated = []
